==> jc-1.4.0.tar.gz: gnu/java/util/prefs/FileBasedFactory.c <==
// public class gnu.java.util.prefs.FileBasedFactory

// class file dependencies
// @dep_class 43799c8bf604478c gnu_java_util_prefs_FileBasedFactory
// @dep_class bf29ff960d5ec1d0 java_lang_Class
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class c80f4aedd95be265 java_lang_String
// @dep_class bf90b87eae48dd53 java_util_prefs_Preferences
// @dep_class b8488ad37f1363a1 java_util_prefs_PreferencesFactory

// header file dependencies
// @dep_header gnu_java_util_prefs_FileBasedFactory
// @dep_header java_lang_Class
// @dep_header java_lang_String
// @dep_header java_util_prefs_Preferences
// @dep_header java_util_prefs_PreferencesFactory

#include "jc_defs.h"

#include "gnu/java/util/prefs/FileBasedFactory.h"
#include "java/lang/Class.h"
#include "java/lang/String.h"
#include "java/util/prefs/Preferences.h"
#include "java/util/prefs/PreferencesFactory.h"

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// public void <init>()
//

static _jc_linenum _jc_gnu_java_util_prefs_FileBasedFactory$linenum_table$_init$52f4ad9f2989aeee[];

static const unsigned char _jc_gnu_java_util_prefs_FileBasedFactory$param_ptypes$_init$52f4ad9f2989aeee[] = { 
_JC_TYPE_VOID };

_jc_method _jc_gnu_java_util_prefs_FileBasedFactory$method_info$_init$52f4ad9f2989aeee = {
	.name=			"<init>",
	.signature=		"()V",
	.class=			&_jc_gnu_java_util_prefs_FileBasedFactory$type,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_gnu_java_util_prefs_FileBasedFactory$param_ptypes$_init$52f4ad9f2989aeee,
	.signature_hash=	_JC_JLONG(0x52f4ad9f2989aeee),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_gnu_java_util_prefs_FileBasedFactory$method$_init$52f4ad9f2989aeee,
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_gnu_java_util_prefs_FileBasedFactory$linenum_table$_init$52f4ad9f2989aeee
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(gnu_java_util_prefs_FileBasedFactory, _init$52f4ad9f2989aeee);

void
_jc_gnu_java_util_prefs_FileBasedFactory$method$_init$52f4ad9f2989aeee(_jc_env *const env, _jc_gnu_java_util_prefs_FileBasedFactory$object *this)
{
	struct _jc_gnu_java_util_prefs_FileBasedFactory$object *r0;

	r0 = this;
	_JC_LINE_NUMBER(48);				// 0
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// public java.util.prefs.Preferences systemRoot()
//

static _jc_linenum _jc_gnu_java_util_prefs_FileBasedFactory$linenum_table$systemRoot$bf0a6df2e99738a0[];

static const unsigned char _jc_gnu_java_util_prefs_FileBasedFactory$param_ptypes$systemRoot$bf0a6df2e99738a0[] = { 
_JC_TYPE_REFERENCE };

_jc_method _jc_gnu_java_util_prefs_FileBasedFactory$method_info$systemRoot$bf0a6df2e99738a0 = {
	.name=			"systemRoot",
	.signature=		"()Ljava/util/prefs/Preferences;",
	.class=			&_jc_gnu_java_util_prefs_FileBasedFactory$type,
	.return_type=		&_jc_java_util_prefs_Preferences$type,
	.param_ptypes=		&_jc_gnu_java_util_prefs_FileBasedFactory$param_ptypes$systemRoot$bf0a6df2e99738a0,
	.signature_hash=	_JC_JLONG(0xbf0a6df2e99738a0),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_gnu_java_util_prefs_FileBasedFactory$method$systemRoot$bf0a6df2e99738a0,
	.vtable_index=		_JC_OFFSETOF(struct _jc_gnu_java_util_prefs_FileBasedFactory$vtable, gnu_java_util_prefs_FileBasedFactory.systemRoot$bf0a6df2e99738a0) / sizeof(void *),
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_gnu_java_util_prefs_FileBasedFactory$linenum_table$systemRoot$bf0a6df2e99738a0
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(gnu_java_util_prefs_FileBasedFactory, systemRoot$bf0a6df2e99738a0);

_jc_java_util_prefs_Preferences$object *
_jc_gnu_java_util_prefs_FileBasedFactory$method$systemRoot$bf0a6df2e99738a0(_jc_env *const env, _jc_gnu_java_util_prefs_FileBasedFactory$object *this)
{
	struct _jc_gnu_java_util_prefs_FileBasedFactory$object *r0;

	r0 = this;
	_JC_LINE_NUMBER(51);				// 0
	return _JC_NULL;
}

//
// public java.util.prefs.Preferences userRoot()
//

static _jc_linenum _jc_gnu_java_util_prefs_FileBasedFactory$linenum_table$userRoot$b327c33849f7289d[];

static const unsigned char _jc_gnu_java_util_prefs_FileBasedFactory$param_ptypes$userRoot$b327c33849f7289d[] = { 
_JC_TYPE_REFERENCE };

_jc_method _jc_gnu_java_util_prefs_FileBasedFactory$method_info$userRoot$b327c33849f7289d = {
	.name=			"userRoot",
	.signature=		"()Ljava/util/prefs/Preferences;",
	.class=			&_jc_gnu_java_util_prefs_FileBasedFactory$type,
	.return_type=		&_jc_java_util_prefs_Preferences$type,
	.param_ptypes=		&_jc_gnu_java_util_prefs_FileBasedFactory$param_ptypes$userRoot$b327c33849f7289d,
	.signature_hash=	_JC_JLONG(0xb327c33849f7289d),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_gnu_java_util_prefs_FileBasedFactory$method$userRoot$b327c33849f7289d,
	.vtable_index=		_JC_OFFSETOF(struct _jc_gnu_java_util_prefs_FileBasedFactory$vtable, gnu_java_util_prefs_FileBasedFactory.userRoot$b327c33849f7289d) / sizeof(void *),
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_gnu_java_util_prefs_FileBasedFactory$linenum_table$userRoot$b327c33849f7289d
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(gnu_java_util_prefs_FileBasedFactory, userRoot$b327c33849f7289d);

_jc_java_util_prefs_Preferences$object *
_jc_gnu_java_util_prefs_FileBasedFactory$method$userRoot$b327c33849f7289d(_jc_env *const env, _jc_gnu_java_util_prefs_FileBasedFactory$object *this)
{
	struct _jc_gnu_java_util_prefs_FileBasedFactory$object *r0;

	r0 = this;
	_JC_LINE_NUMBER(55);				// 0
	return _JC_NULL;
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_gnu_java_util_prefs_FileBasedFactory$methods[] = {
	&_jc_gnu_java_util_prefs_FileBasedFactory$method_info$_init$52f4ad9f2989aeee,
	&_jc_gnu_java_util_prefs_FileBasedFactory$method_info$systemRoot$bf0a6df2e99738a0,
	&_jc_gnu_java_util_prefs_FileBasedFactory$method_info$userRoot$b327c33849f7289d
};

/************************************************************************
 *			      Interface list				*
 ************************************************************************/

// Directly implemented interfaces
static _jc_type *const _jc_gnu_java_util_prefs_FileBasedFactory$interfaces[] = {
	&_jc_java_util_prefs_PreferencesFactory$type
};

/************************************************************************
 *			   Interface hash table				*
 ************************************************************************/

#if _JC_IMETHOD_HASHSIZE != 128
#error "_JC_IMETHOD_HASHSIZE has the wrong value (should be 128)"
#endif

// Interface lookup hash table buckets
static _jc_method *_jc_gnu_java_util_prefs_FileBasedFactory$imethod_hash_bucket_29[] = {
	&_jc_gnu_java_util_prefs_FileBasedFactory$method_info$userRoot$b327c33849f7289d,
	_JC_NULL
};
static _jc_method *_jc_gnu_java_util_prefs_FileBasedFactory$imethod_hash_bucket_32[] = {
	&_jc_gnu_java_util_prefs_FileBasedFactory$method_info$systemRoot$bf0a6df2e99738a0,
	_JC_NULL
};

// Interface lookup hash table
static _jc_method **_jc_gnu_java_util_prefs_FileBasedFactory$imethod_hash_table[_JC_IMETHOD_HASHSIZE] = {
	[29]=	_jc_gnu_java_util_prefs_FileBasedFactory$imethod_hash_bucket_29,
	[32]=	_jc_gnu_java_util_prefs_FileBasedFactory$imethod_hash_bucket_32
};

// Interface "quick" lookup hash table
static const void *_jc_gnu_java_util_prefs_FileBasedFactory$imethod_quick_table[_JC_IMETHOD_HASHSIZE] = {
	[29]=	&_jc_gnu_java_util_prefs_FileBasedFactory$method$userRoot$b327c33849f7289d,
	[32]=	&_jc_gnu_java_util_prefs_FileBasedFactory$method$systemRoot$bf0a6df2e99738a0
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_gnu_java_util_prefs_FileBasedFactory$instanceof_hash_bucket_12[] = {
	&_jc_gnu_java_util_prefs_FileBasedFactory$type,
	_JC_NULL
};
static _jc_type *const _jc_gnu_java_util_prefs_FileBasedFactory$instanceof_hash_bucket_33[] = {
	&_jc_java_util_prefs_PreferencesFactory$type,
	_JC_NULL
};
static _jc_type *const _jc_gnu_java_util_prefs_FileBasedFactory$instanceof_hash_bucket_113[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_gnu_java_util_prefs_FileBasedFactory$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[12]=	_jc_gnu_java_util_prefs_FileBasedFactory$instanceof_hash_bucket_12,
	[33]=	_jc_gnu_java_util_prefs_FileBasedFactory$instanceof_hash_bucket_33,
	[113]=	_jc_gnu_java_util_prefs_FileBasedFactory$instanceof_hash_bucket_113
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_gnu_java_util_prefs_FileBasedFactory$class_depends[] = {
	{ "java/lang/Class",	_JC_JLONG(0xbf29ff960d5ec1d0) },
	{ "java/lang/Object",	_JC_JLONG(0x2a7152deee1944f1) },
	{ "java/lang/String",	_JC_JLONG(0xc80f4aedd95be265) },
	{ "java/util/prefs/Preferences",	_JC_JLONG(0xbf90b87eae48dd53) },
	{ "java/util/prefs/PreferencesFactory",	_JC_JLONG(0xb8488ad37f1363a1) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_gnu_java_util_prefs_FileBasedFactory$vtype _jc_gnu_java_util_prefs_FileBasedFactory$type = {
    .type= {
	.name=			"gnu/java/util/prefs/FileBasedFactory",
	.superclass=		&_jc_java_lang_Object$type,
	.access_flags=		_JC_ACC_PUBLIC,
	.flags=			_JC_TYPE_REFERENCE,
	.num_interfaces=sizeof(_jc_gnu_java_util_prefs_FileBasedFactory$interfaces) / sizeof(*_jc_gnu_java_util_prefs_FileBasedFactory$interfaces),
	.interfaces=		_jc_gnu_java_util_prefs_FileBasedFactory$interfaces,
	.imethod_hash_table=	_jc_gnu_java_util_prefs_FileBasedFactory$imethod_hash_table,
	.imethod_quick_table=	_jc_gnu_java_util_prefs_FileBasedFactory$imethod_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		13,
		.hash=			_JC_JLONG(0x43799c8bf604478c),
		.source_file=		"FileBasedFactory.java",
		.instance_size=		sizeof(_jc_gnu_java_util_prefs_FileBasedFactory$refs) + sizeof(_jc_gnu_java_util_prefs_FileBasedFactory$object),
		.num_virtual_refs=	0,
		.num_methods=		sizeof(_jc_gnu_java_util_prefs_FileBasedFactory$methods) / sizeof(*_jc_gnu_java_util_prefs_FileBasedFactory$methods),
		.methods=		_jc_gnu_java_util_prefs_FileBasedFactory$methods,
		.instanceof_hash_table=	_jc_gnu_java_util_prefs_FileBasedFactory$instanceof_hash_table,
		.num_class_depends=		sizeof(_jc_gnu_java_util_prefs_FileBasedFactory$class_depends) / sizeof(*_jc_gnu_java_util_prefs_FileBasedFactory$class_depends),
		.class_depends=		_jc_gnu_java_util_prefs_FileBasedFactory$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=
		&_jc_java_lang_Object$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.gnu_java_util_prefs_FileBasedFactory= {
	    .systemRoot$bf0a6df2e99738a0=
		&_jc_gnu_java_util_prefs_FileBasedFactory$method$systemRoot$bf0a6df2e99738a0,
	    .userRoot$b327c33849f7289d=
		&_jc_gnu_java_util_prefs_FileBasedFactory$method$userRoot$b327c33849f7289d,
	},
    }
};

==> jc-1.4.5.tar.gz: gnu/java/util/prefs/FileBasedFactory.c <==
// public class gnu.java.util.prefs.FileBasedFactory

// class file dependencies
// @dep_class 43799c8bf604478c gnu_java_util_prefs_FileBasedFactory
// @dep_class 764eb76bc6714ae3 java_lang_Class
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 195095aa45046bea java_lang_String
// @dep_class bf90b87eae48dd53 java_util_prefs_Preferences
// @dep_class b8488ad37f1363a1 java_util_prefs_PreferencesFactory

// header file dependencies
// @dep_header gnu_java_util_prefs_FileBasedFactory
// @dep_header java_lang_Class
// @dep_header java_lang_String
// @dep_header java_util_prefs_Preferences
// @dep_header java_util_prefs_PreferencesFactory

#include "jc_defs.h"

#include "gnu/java/util/prefs/FileBasedFactory.h"
#include "java/lang/Class.h"
#include "java/lang/String.h"
#include "java/util/prefs/Preferences.h"
#include "java/util/prefs/PreferencesFactory.h"

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// public void <init>()
//

static _jc_linenum _jc_gnu_java_util_prefs_FileBasedFactory$linenum_table$_init$52f4ad9f2989aeee[];

static const unsigned char _jc_gnu_java_util_prefs_FileBasedFactory$param_ptypes$_init$52f4ad9f2989aeee[] = { 
_JC_TYPE_VOID };

_jc_method _jc_gnu_java_util_prefs_FileBasedFactory$method_info$_init$52f4ad9f2989aeee = {
	.name=			"<init>",
	.signature=		"()V",
	.class=			&_jc_gnu_java_util_prefs_FileBasedFactory$type,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_gnu_java_util_prefs_FileBasedFactory$param_ptypes$_init$52f4ad9f2989aeee,
	.signature_hash=	_JC_JLONG(0x52f4ad9f2989aeee),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_gnu_java_util_prefs_FileBasedFactory$method$_init$52f4ad9f2989aeee,
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_gnu_java_util_prefs_FileBasedFactory$linenum_table$_init$52f4ad9f2989aeee
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(gnu_java_util_prefs_FileBasedFactory, _init$52f4ad9f2989aeee);

void _JC_JCNI_ATTR
_jc_gnu_java_util_prefs_FileBasedFactory$method$_init$52f4ad9f2989aeee(_jc_env *const env, _jc_gnu_java_util_prefs_FileBasedFactory$object *this)
{
	struct _jc_gnu_java_util_prefs_FileBasedFactory$object *r0;

	r0 = this;
	_JC_LINE_NUMBER(48);				// 0
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// public java.util.prefs.Preferences systemRoot()
//

static _jc_linenum _jc_gnu_java_util_prefs_FileBasedFactory$linenum_table$systemRoot$bf0a6df2e99738a0[];

static const unsigned char _jc_gnu_java_util_prefs_FileBasedFactory$param_ptypes$systemRoot$bf0a6df2e99738a0[] = { 
_JC_TYPE_REFERENCE };

_jc_method _jc_gnu_java_util_prefs_FileBasedFactory$method_info$systemRoot$bf0a6df2e99738a0 = {
	.name=			"systemRoot",
	.signature=		"()Ljava/util/prefs/Preferences;",
	.class=			&_jc_gnu_java_util_prefs_FileBasedFactory$type,
	.return_type=		&_jc_java_util_prefs_Preferences$type,
	.param_ptypes=		&_jc_gnu_java_util_prefs_FileBasedFactory$param_ptypes$systemRoot$bf0a6df2e99738a0,
	.signature_hash=	_JC_JLONG(0xbf0a6df2e99738a0),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_gnu_java_util_prefs_FileBasedFactory$method$systemRoot$bf0a6df2e99738a0,
	.vtable_index=		_JC_OFFSETOF(struct _jc_gnu_java_util_prefs_FileBasedFactory$vtable, gnu_java_util_prefs_FileBasedFactory.systemRoot$bf0a6df2e99738a0) / sizeof(void *),
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_gnu_java_util_prefs_FileBasedFactory$linenum_table$systemRoot$bf0a6df2e99738a0
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(gnu_java_util_prefs_FileBasedFactory, systemRoot$bf0a6df2e99738a0);

_jc_java_util_prefs_Preferences$object * _JC_JCNI_ATTR
_jc_gnu_java_util_prefs_FileBasedFactory$method$systemRoot$bf0a6df2e99738a0(_jc_env *const env, _jc_gnu_java_util_prefs_FileBasedFactory$object *this)
{
	struct _jc_gnu_java_util_prefs_FileBasedFactory$object *r0;

	r0 = this;
	_JC_LINE_NUMBER(51);				// 0
	return _JC_NULL;
}

//
// public java.util.prefs.Preferences userRoot()
//

static _jc_linenum _jc_gnu_java_util_prefs_FileBasedFactory$linenum_table$userRoot$b327c33849f7289d[];

static const unsigned char _jc_gnu_java_util_prefs_FileBasedFactory$param_ptypes$userRoot$b327c33849f7289d[] = { 
_JC_TYPE_REFERENCE };

_jc_method _jc_gnu_java_util_prefs_FileBasedFactory$method_info$userRoot$b327c33849f7289d = {
	.name=			"userRoot",
	.signature=		"()Ljava/util/prefs/Preferences;",
	.class=			&_jc_gnu_java_util_prefs_FileBasedFactory$type,
	.return_type=		&_jc_java_util_prefs_Preferences$type,
	.param_ptypes=		&_jc_gnu_java_util_prefs_FileBasedFactory$param_ptypes$userRoot$b327c33849f7289d,
	.signature_hash=	_JC_JLONG(0xb327c33849f7289d),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_gnu_java_util_prefs_FileBasedFactory$method$userRoot$b327c33849f7289d,
	.vtable_index=		_JC_OFFSETOF(struct _jc_gnu_java_util_prefs_FileBasedFactory$vtable, gnu_java_util_prefs_FileBasedFactory.userRoot$b327c33849f7289d) / sizeof(void *),
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_gnu_java_util_prefs_FileBasedFactory$linenum_table$userRoot$b327c33849f7289d
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(gnu_java_util_prefs_FileBasedFactory, userRoot$b327c33849f7289d);

_jc_java_util_prefs_Preferences$object * _JC_JCNI_ATTR
_jc_gnu_java_util_prefs_FileBasedFactory$method$userRoot$b327c33849f7289d(_jc_env *const env, _jc_gnu_java_util_prefs_FileBasedFactory$object *this)
{
	struct _jc_gnu_java_util_prefs_FileBasedFactory$object *r0;

	r0 = this;
	_JC_LINE_NUMBER(55);				// 0
	return _JC_NULL;
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_gnu_java_util_prefs_FileBasedFactory$methods[] = {
	&_jc_gnu_java_util_prefs_FileBasedFactory$method_info$_init$52f4ad9f2989aeee,
	&_jc_gnu_java_util_prefs_FileBasedFactory$method_info$systemRoot$bf0a6df2e99738a0,
	&_jc_gnu_java_util_prefs_FileBasedFactory$method_info$userRoot$b327c33849f7289d
};

/************************************************************************
 *			      Interface list				*
 ************************************************************************/

// Directly implemented interfaces
static _jc_type *const _jc_gnu_java_util_prefs_FileBasedFactory$interfaces[] = {
	&_jc_java_util_prefs_PreferencesFactory$type
};

/************************************************************************
 *			   Interface hash table				*
 ************************************************************************/

#if _JC_IMETHOD_HASHSIZE != 128
#error "_JC_IMETHOD_HASHSIZE has the wrong value (should be 128)"
#endif

// Interface lookup hash table buckets
static _jc_method *_jc_gnu_java_util_prefs_FileBasedFactory$imethod_hash_bucket_29[] = {
	&_jc_gnu_java_util_prefs_FileBasedFactory$method_info$userRoot$b327c33849f7289d,
	_JC_NULL
};
static _jc_method *_jc_gnu_java_util_prefs_FileBasedFactory$imethod_hash_bucket_32[] = {
	&_jc_gnu_java_util_prefs_FileBasedFactory$method_info$systemRoot$bf0a6df2e99738a0,
	_JC_NULL
};

// Interface lookup hash table
static _jc_method **_jc_gnu_java_util_prefs_FileBasedFactory$imethod_hash_table[_JC_IMETHOD_HASHSIZE] = {
	[29]=	_jc_gnu_java_util_prefs_FileBasedFactory$imethod_hash_bucket_29,
	[32]=	_jc_gnu_java_util_prefs_FileBasedFactory$imethod_hash_bucket_32
};

// Interface "quick" lookup hash table
static const void *_jc_gnu_java_util_prefs_FileBasedFactory$imethod_quick_table[_JC_IMETHOD_HASHSIZE] = {
	[29]=	&_jc_gnu_java_util_prefs_FileBasedFactory$method$userRoot$b327c33849f7289d,
	[32]=	&_jc_gnu_java_util_prefs_FileBasedFactory$method$systemRoot$bf0a6df2e99738a0
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_gnu_java_util_prefs_FileBasedFactory$instanceof_hash_bucket_12[] = {
	&_jc_gnu_java_util_prefs_FileBasedFactory$type,
	_JC_NULL
};
static _jc_type *const _jc_gnu_java_util_prefs_FileBasedFactory$instanceof_hash_bucket_33[] = {
	&_jc_java_util_prefs_PreferencesFactory$type,
	_JC_NULL
};
static _jc_type *const _jc_gnu_java_util_prefs_FileBasedFactory$instanceof_hash_bucket_101[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_gnu_java_util_prefs_FileBasedFactory$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[12]=	_jc_gnu_java_util_prefs_FileBasedFactory$instanceof_hash_bucket_12,
	[33]=	_jc_gnu_java_util_prefs_FileBasedFactory$instanceof_hash_bucket_33,
	[101]=	_jc_gnu_java_util_prefs_FileBasedFactory$instanceof_hash_bucket_101
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_gnu_java_util_prefs_FileBasedFactory$class_depends[] = {
	{ "java/lang/Class",	_JC_JLONG(0x764eb76bc6714ae3) },
	{ "java/lang/Object",	_JC_JLONG(0x1c4f1fc002fc96e5) },
	{ "java/lang/String",	_JC_JLONG(0x195095aa45046bea) },
	{ "java/util/prefs/Preferences",	_JC_JLONG(0xbf90b87eae48dd53) },
	{ "java/util/prefs/PreferencesFactory",	_JC_JLONG(0xb8488ad37f1363a1) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_gnu_java_util_prefs_FileBasedFactory$vtype _jc_gnu_java_util_prefs_FileBasedFactory$type = {
    .type= {
	.name=			"gnu/java/util/prefs/FileBasedFactory",
	.superclass=		&_jc_java_lang_Object$type,
	.access_flags=		_JC_ACC_PUBLIC,
	.flags=			_JC_TYPE_REFERENCE,
	.num_interfaces=sizeof(_jc_gnu_java_util_prefs_FileBasedFactory$interfaces) / sizeof(*_jc_gnu_java_util_prefs_FileBasedFactory$interfaces),
	.interfaces=		_jc_gnu_java_util_prefs_FileBasedFactory$interfaces,
	.imethod_hash_table=	_jc_gnu_java_util_prefs_FileBasedFactory$imethod_hash_table,
	.imethod_quick_table=	_jc_gnu_java_util_prefs_FileBasedFactory$imethod_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		13,
		.hash=			_JC_JLONG(0x43799c8bf604478c),
		.source_file=		"FileBasedFactory.java",
		.instance_size=		sizeof(_jc_gnu_java_util_prefs_FileBasedFactory$refs) + sizeof(_jc_gnu_java_util_prefs_FileBasedFactory$object),
		.num_virtual_refs=	0,
		.num_methods=		sizeof(_jc_gnu_java_util_prefs_FileBasedFactory$methods) / sizeof(*_jc_gnu_java_util_prefs_FileBasedFactory$methods),
		.methods=		_jc_gnu_java_util_prefs_FileBasedFactory$methods,
		.instanceof_hash_table=	_jc_gnu_java_util_prefs_FileBasedFactory$instanceof_hash_table,
		.num_class_depends=		sizeof(_jc_gnu_java_util_prefs_FileBasedFactory$class_depends) / sizeof(*_jc_gnu_java_util_prefs_FileBasedFactory$class_depends),
		.class_depends=		_jc_gnu_java_util_prefs_FileBasedFactory$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=
		&_jc_java_lang_Object$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.gnu_java_util_prefs_FileBasedFactory= {
	    .systemRoot$bf0a6df2e99738a0=
		&_jc_gnu_java_util_prefs_FileBasedFactory$method$systemRoot$bf0a6df2e99738a0,
	    .userRoot$b327c33849f7289d=
		&_jc_gnu_java_util_prefs_FileBasedFactory$method$userRoot$b327c33849f7289d,
	},
    }
};
